@@ -153,11 +153,8 @@ magconf_setting_init (const gchar *id,
 	
     value->source 	= g_strdup (DEFAULT_MAGNIFIER_SOURCE);
     value->target 	= g_strdup (DEFAULT_MAGNIFIER_TARGET);
-    (value->zp).left	= size_x / 2;
+    (value->zp).left	= DEFAULT_MAGNIFIER_ZP_LEFT;
     (value->zp).top	= DEFAULT_MAGNIFIER_ZP_TOP;
-    (value->zp).height	= size_y;
-    (value->zp).width	= size_x;
-
     (value->zp).height	= DEFAULT_MAGNIFIER_ZP_HEIGHT;
     (value->zp).width	= DEFAULT_MAGNIFIER_ZP_WIDTH;
     value->zoomfactorx	= DEFAULT_MAGNIFIER_ZOOM_FACTOR_XY;
