@@ -1,7 +1,7 @@
 /* libsrconf.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -52,9 +52,10 @@
 #define DEFAULT_BRAILLE_CURSOR_STYLE		"underline"
 #define DEFAULT_BRAILLE_TRANSLATION 		"de"
 #define DEFAULT_BRAILLE_DEVICE 			"BRLTTY"
-#define DEFAULT_BRAILLE_DEVICE_INDEX 		0
+#define DEFAULT_BRAILLE_DEVICE_INDEX 		-1
 #define DEFAULT_BRAILLE_DEVICE_COUNT		0
 #define DEFAULT_BRAILLE_PORT_NO 		-1
+#define DEFAULT_BRAILLE_PORT 			NULL
 #define DEFAULT_BRAILLE_FILL_CHAR 		"##"
 #define DEFAULT_BRAILLE_STATUS_CELL 		"CursorPos"
 #define DEFAULT_BRAILLE_OPTICAL_SENSOR 		0
@@ -96,7 +97,7 @@
 #define SPEECH_PITCH_STEP			25
 
 #define MAX_SPEECH_RATE				400
-#define MIN_SPEECH_RATE				100
+#define MIN_SPEECH_RATE				30
 #define MAX_SPEECH_PITCH 			500
 #define MIN_SPEECH_PITCH 			10
 #define MAX_SPEECH_VOLUME 			100
@@ -205,6 +206,7 @@
 #define BRAILLE_TRANSLATION 			"translation_table"
 #define BRAILLE_DEVICE 				"device"
 #define BRAILLE_PORT_NO 			"port_no"
+#define BRAILLE_PORT 				"port"
 #define BRAILLE_FILL_CHAR 			"fill_char"
 #define BRAILLE_STATUS_CELL 			"status"
 #define BRAILLE_OPTICAL_SENSOR 			"optical"
