@@ -846,7 +846,7 @@ srle_set_acc (SRLEvent *event)
 		srle_acc_has_role (event, SPI_ROLE_TABLE) &&
 		!srle_acc_has_state (event, SPI_STATE_MANAGES_DESCENDANTS))
     {
-	event->acc = srl_get_focused_from_acc (srle_get_acc (event));
+	event->acc = srl_get_focused_from_acc ((Accessible*)srle_get_acc (event));
     }
     else if (srle_has_type (event, SRL_EVENT_ACTIVE_DESCENDANT_CHANGED))
     {
